==> anwiba-spatial-data-ckan-1.1.158-sources.jar: net/anwiba/spatial/ckan/json/schema/v1_0/Tag.java <==
//Copyright (c) 2017 by Andreas W. Bartels
package net.anwiba.spatial.ckan.json.schema.v1_0;

import java.util.LinkedHashMap;
import java.util.Map;
import java.util.Objects;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonProperty;

public class Tag
    extends Named
{

    private String vocabulary_id = null;
    private String state = null;
    private String id = null;
    private final Map<java.lang.String, Object> _unknownMembers = new LinkedHashMap<java.lang.String, Object>();

    @JsonProperty("vocabulary_id")
    public void setVocabulary_id(final String vocabulary_id) {
        this.vocabulary_id = vocabulary_id;
    }

    @JsonProperty("vocabulary_id")
    public String getVocabulary_id() {
        return this.vocabulary_id;
    }

    @JsonProperty("state")
    public void setState(final String state) {
        this.state = state;
    }

    @JsonProperty("state")
    public String getState() {
        return this.state;
    }

    @JsonProperty("id")
    public void setId(final String id) {
        this.id = id;
    }

    @JsonProperty("id")
    public String getId() {
        return this.id;
    }

    @JsonAnySetter
    public void set(final java.lang.String name, final Object value) {
        Objects.requireNonNull(name);
        this._unknownMembers.put(name, value);
    }

    @JsonAnyGetter
    public Map<java.lang.String, Object> get() {
        if (this._unknownMembers.isEmpty()) {
            return null;
        }
        return this._unknownMembers;
    }

}

==> anwiba-spatial-data-ckan-1.2.50-sources.jar: net/anwiba/spatial/ckan/json/schema/v1_0/Tag.java <==
//Copyright (c) 2017 by Andreas W. Bartels
package net.anwiba.spatial.ckan.json.schema.v1_0;

import java.util.LinkedHashMap;
import java.util.Map;
import java.util.Objects;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonProperty;

public class Tag
    extends Named
{

    private String vocabulary_id = null;
    private String state = null;
    private String id = null;
    private final Map<java.lang.String, Object> _unknownMembers = new LinkedHashMap<>();

    @JsonProperty("vocabulary_id")
    public void setVocabulary_id(final String vocabulary_id) {
        this.vocabulary_id = vocabulary_id;
    }

    @JsonProperty("vocabulary_id")
    public String getVocabulary_id() {
        return this.vocabulary_id;
    }

    @JsonProperty("state")
    public void setState(final String state) {
        this.state = state;
    }

    @JsonProperty("state")
    public String getState() {
        return this.state;
    }

    @JsonProperty("id")
    public void setId(final String id) {
        this.id = id;
    }

    @JsonProperty("id")
    public String getId() {
        return this.id;
    }

    @JsonAnySetter
    public void set(final java.lang.String name, final Object value) {
        Objects.requireNonNull(name);
        this._unknownMembers.put(name, value);
    }

    @JsonAnyGetter
    public Map<java.lang.String, Object> get() {
        if (this._unknownMembers.isEmpty()) {
            return null;
        }
        return this._unknownMembers;
    }

}
